@@ -2,13 +2,18 @@ import os,glob
 from jinja2 import Template,Environment
 import json
 import shutil
-
+# WKMAKE_FILENAME='wkmake.json'
+WKMAKE_FILENAME='wkmake.yaml'
 DEFAULT_CONFIG=dict(
 )
 
 def load_json(f):
     with open(f,'r',encoding='utf-8') as fp:
         return json.load(fp)
+def load_yaml(f):
+    import yaml
+    with open(f,'r',encoding='utf-8') as fp:
+        return yaml.safe_load(fp)
 def check_config(local_config,config):
     assert isinstance(local_config,dict)
     assert isinstance(config,dict)
@@ -26,10 +31,9 @@ def check_config(local_config,config):
         tmp[k]=v
     return tmp
 def read_dir_info(dir):
-    WKMAKE_FILENAME = 'wkmake.json'
     cfg={}
     if os.path.exists(os.path.join(dir, WKMAKE_FILENAME)):
-        cfg = load_json(os.path.join(dir, WKMAKE_FILENAME))
+        cfg = load_yaml(os.path.join(dir, WKMAKE_FILENAME))
     return cfg
 def make_file(src_path,dst_path,config={},overwrite=False):
     if os.path.exists(dst_path):
@@ -65,7 +69,6 @@ def make_recursively(src_path, dst_path, config=None, overwrite=False):
     default=DEFAULT_CONFIG.copy()
     default.update(config)
     config=default
-    WKMAKE_FILENAME='wkmake.json'
     if os.path.isfile(src_path):
         make_file(src_path,dst_path,config,overwrite=overwrite)
         print('Render template from %s to %s.' % (src_path,dst_path))
@@ -73,7 +76,7 @@ def make_recursively(src_path, dst_path, config=None, overwrite=False):
         if os.path.basename(src_path)=='__pycache__':
             return
         if os.path.exists(os.path.join(src_path,WKMAKE_FILENAME)):
-            cfg=load_json(os.path.join(src_path,WKMAKE_FILENAME))
+            cfg=load_yaml(os.path.join(src_path,WKMAKE_FILENAME))
             config=check_config(cfg,config)
         if not os.path.exists(dst_path):
             os.makedirs(dst_path)
@@ -89,7 +92,7 @@ def make_from_files(src,dst,config_files,overwrite=False):
     class Config(ConfigBase):
         pass
     for cfg in config_files:
-        cfg=load_json(cfg)
+        cfg=load_yaml(cfg)
         Config.update(**cfg)
     make_recursively(src,dst,Config(),overwrite=overwrite)
 
